

/* mono button: ColorA1 */
#define ColorA1_offo_width 37
#define ColorA1_offo_height 14
static char ColorA1_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9a, 0xc1, 0xa1, 0x83,
  0x03, 0x66, 0x22, 0x62, 0x44, 0x04, 0x22, 0x12, 0x24, 0x24, 0x08, 0x22,
  0x12, 0x24, 0x24, 0x08, 0x22, 0x12, 0x24, 0x24, 0x08, 0x22, 0x22, 0x22,
  0x44, 0x04, 0x22, 0xc2, 0x21, 0x84, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char ColorA1_offo_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0xff, 0xe3, 0xf3, 0xc7, 0x07, 0xff, 0xf7, 0xf7, 0xef,
  0x0f, 0xff, 0xff, 0xff, 0xff, 0x1f, 0xff, 0x7f, 0xff, 0xfe, 0x1e, 0x77,
  0x3f, 0x7e, 0x7e, 0x1c, 0x77, 0x7f, 0x7f, 0xfe, 0x1e, 0x77, 0xff, 0x7f,
  0xfe, 0x1f, 0x77, 0xf7, 0x77, 0xee, 0x0f, 0x77, 0xe7, 0x73, 0xce, 0x07,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int ColorA1_offo_breaks[] = { 11, 20, 28, 37 };
static ButtonLabel ColorA1_offo = {
  (unsigned char *)ColorA1_offo_label, (unsigned char *)ColorA1_offo_mask,
  ColorA1_offo_width, ColorA1_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 4, 0, ColorA1_offo_breaks };
#define ColorA1_offi_width 35
#define ColorA1_offi_height 14
static char ColorA1_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xdf, 0xf1, 0xf9, 0xf1,
  0x01, 0x33, 0x1b, 0x1b, 0x1b, 0x03, 0x33, 0x1b, 0x1b, 0x1b, 0x03, 0x33,
  0x1b, 0x1b, 0x1b, 0x03, 0x33, 0x1b, 0x1b, 0x1b, 0x03, 0x33, 0x1b, 0x1b,
  0x1b, 0x03, 0x33, 0xf3, 0x19, 0xf3, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char ColorA1_offi_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0xff, 0xfb, 0xff, 0xfb, 0x03, 0xff, 0xff, 0xff, 0xff,
  0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xff, 0xbf, 0xbf, 0xbf, 0x07, 0xff,
  0xbf, 0xbf, 0xbf, 0x07, 0xff, 0xbf, 0xbf, 0xbf, 0x07, 0xff, 0xff, 0xbf,
  0xff, 0x07, 0xff, 0xff, 0xbf, 0xff, 0x07, 0xff, 0xff, 0xbf, 0xff, 0x03,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int ColorA1_offi_breaks[] = { 11, 19, 27, 35 };
static ButtonLabel ColorA1_offi = {
  (unsigned char *)ColorA1_offi_label, (unsigned char *)ColorA1_offi_mask,
  ColorA1_offi_width, ColorA1_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 4, 0, ColorA1_offi_breaks };
static ButtonLook ColorA1_look = {
  &ColorA1_offo, NULL, &ColorA1_offo, NULL,
  &ColorA1_offi, NULL, &ColorA1_offi, NULL };
static ButtonFeel ColorA1_feel = {
  "ColorA1", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 8, 1, 0, 0 } };
/* ovlay button: ColorA2 */
#define ColorA2_offo_width 38
#define ColorA2_offo_height 14
static char ColorA2_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,
  0x08, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x38, 0x04, 0x89, 0x43,
  0x10, 0x44, 0x04, 0x49, 0x44, 0x10, 0x82, 0x88, 0x08, 0x86, 0x08, 0x82,
  0x88, 0x88, 0x85, 0x08, 0x82, 0x50, 0x48, 0x04, 0x05, 0x44, 0x50, 0x48,
  0x04, 0x05, 0x38, 0x20, 0x88, 0x0b, 0x02, 0x00, 0x00, 0x00, 0x00, 0x02,
  0x00, 0x00, 0x00, 0x40, 0x02, 0x00, 0x00, 0x00, 0x80, 0x01 };
static char ColorA2_offo_mask[] = {
  0x00, 0x00, 0x1c, 0x00, 0x00, 0x00, 0x00, 0x1c, 0x00, 0x00, 0x00, 0x00,
  0x1c, 0x00, 0x00, 0x7c, 0x8e, 0xdf, 0xe7, 0x38, 0xfe, 0x8e, 0xff, 0xef,
  0x38, 0xff, 0xdf, 0xff, 0xef, 0x3d, 0xef, 0xdf, 0xff, 0xef, 0x3d, 0xc7,
  0xfd, 0xfd, 0xcf, 0x1f, 0xef, 0xfd, 0xfd, 0xcf, 0x1f, 0xff, 0xf9, 0xfc,
  0x9f, 0x0f, 0xfe, 0xf8, 0xfc, 0x9f, 0x0f, 0x7c, 0x70, 0xdc, 0xff, 0x07,
  0x00, 0x00, 0x00, 0xe0, 0x07, 0x00, 0x00, 0x00, 0xe0, 0x07 };
static int ColorA2_offo_breaks[] = { 9, 18, 21, 29, 38 };
static ButtonLabel ColorA2_offo = {
  (unsigned char *)ColorA2_offo_label, (unsigned char *)ColorA2_offo_mask,
  ColorA2_offo_width, ColorA2_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, ColorA2_offo_breaks };
#define ColorA2_offi_width 36
#define ColorA2_offi_height 14
static char ColorA2_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00,
  0x06, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x3e, 0xc3, 0xe6, 0x31,
  0x06, 0x63, 0xc3, 0x36, 0x33, 0x06, 0x63, 0x66, 0x06, 0x63, 0x06, 0x63,
  0x66, 0xe6, 0x63, 0x03, 0x63, 0x24, 0x36, 0x43, 0x03, 0x63, 0x3c, 0x36,
  0xc3, 0x03, 0x3e, 0x18, 0xe6, 0x86, 0x01, 0x00, 0x00, 0x00, 0x80, 0x01,
  0x00, 0x00, 0x00, 0xb0, 0x01, 0x00, 0x00, 0x00, 0xe0, 0x00 };
static char ColorA2_offi_mask[] = {
  0x00, 0x00, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00, 0x00,
  0x0f, 0x00, 0x00, 0xff, 0xe7, 0xff, 0x7b, 0x0f, 0xff, 0xe7, 0xff, 0x7f,
  0x0f, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xf7, 0xff, 0xff, 0xff, 0x0f, 0xf7,
  0xff, 0xff, 0xf7, 0x0f, 0xf7, 0xff, 0xff, 0xf7, 0x07, 0xff, 0x7e, 0xff,
  0xef, 0x07, 0xff, 0x7e, 0xff, 0xef, 0x07, 0x7f, 0x3c, 0xff, 0xff, 0x03,
  0x00, 0x00, 0x00, 0xf8, 0x03, 0x00, 0x00, 0x00, 0xf8, 0x03 };
static int ColorA2_offi_breaks[] = { 8, 17, 20, 28, 36 };
static ButtonLabel ColorA2_offi = {
  (unsigned char *)ColorA2_offi_label, (unsigned char *)ColorA2_offi_mask,
  ColorA2_offi_width, ColorA2_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, ColorA2_offi_breaks };
static ButtonLook ColorA2_look = {
  &ColorA2_offo, NULL, &ColorA2_offo, NULL,
  &ColorA2_offi, NULL, &ColorA2_offi, NULL };
static ButtonFeel ColorA2_feel = {
  "ColorA2", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 8, 4, 0, 0 } };
/* contbias button: ColorA3 */
#define ColorA3_offo_width 32
#define ColorA3_offo_height 16
static char ColorA3_offo_label[] = {
  0x00, 0x80, 0x80, 0x00, 0x10, 0xc0, 0x41, 0x00, 0x38, 0xe0, 0x23, 0x00,
  0x7c, 0x90, 0x14, 0x00, 0x92, 0x80, 0x08, 0x00, 0x30, 0x80, 0x04, 0x00,
  0x20, 0x00, 0x82, 0x01, 0x60, 0x00, 0x01, 0x03, 0xc0, 0x80, 0x00, 0x06,
  0x80, 0x41, 0x00, 0x04, 0x00, 0x20, 0x01, 0x0c, 0x00, 0x10, 0x01, 0x49,
  0x00, 0x28, 0x09, 0x3e, 0x00, 0xc4, 0x07, 0x1c, 0x00, 0x82, 0x03, 0x08,
  0x00, 0x01, 0x01, 0x00 };
static char ColorA3_offo_mask[] = {
  0x38, 0xe0, 0xf3, 0x03, 0x7c, 0xf0, 0xff, 0x03, 0xfe, 0xf8, 0xff, 0x01,
  0xff, 0xfd, 0xff, 0x00, 0xff, 0xff, 0xff, 0x03, 0xff, 0xff, 0xff, 0x07,
  0xff, 0xc3, 0xdf, 0x0f, 0xf8, 0xe3, 0xcf, 0x1f, 0xf8, 0xf3, 0xc7, 0x1f,
  0xf0, 0xfb, 0xc3, 0xff, 0xe0, 0xff, 0xff, 0xff, 0xc0, 0xff, 0xff, 0xff,
  0x00, 0xff, 0xbf, 0xff, 0x80, 0xff, 0x1f, 0x7f, 0xc0, 0xff, 0x0f, 0x3e,
  0xc0, 0xcf, 0x07, 0x1c };
static ButtonLabel ColorA3_offo = {
  (unsigned char *)ColorA3_offo_label, (unsigned char *)ColorA3_offo_mask,
  ColorA3_offo_width, ColorA3_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 0, 0, NULL };
#define ColorA3_offi_width 32
#define ColorA3_offi_height 16
static char ColorA3_offi_label[] = {
  0x00, 0x80, 0xc0, 0x01, 0x10, 0xc0, 0xe1, 0x00, 0x38, 0xe0, 0x73, 0x00,
  0x7c, 0xf0, 0x3f, 0x00, 0xfe, 0x98, 0x1c, 0x00, 0xba, 0x81, 0x8e, 0x01,
  0x30, 0x00, 0x87, 0x03, 0x70, 0x80, 0x03, 0x07, 0xe0, 0xc0, 0x01, 0x0e,
  0xc0, 0xe1, 0x00, 0x0c, 0x80, 0x71, 0x81, 0x5d, 0x00, 0x38, 0x19, 0x7f,
  0x00, 0xfc, 0x0f, 0x3e, 0x00, 0xce, 0x07, 0x1c, 0x00, 0x87, 0x03, 0x08,
  0x80, 0x03, 0x01, 0x00 };
static char ColorA3_offi_mask[] = {
  0x38, 0xe0, 0xf3, 0x03, 0x7c, 0xf0, 0xff, 0x03, 0xfe, 0xf8, 0xff, 0x01,
  0xff, 0xfd, 0xff, 0x00, 0xff, 0xff, 0xff, 0x03, 0xff, 0xff, 0xff, 0x07,
  0xff, 0xc3, 0xdf, 0x0f, 0xf8, 0xe3, 0xcf, 0x1f, 0xf8, 0xf3, 0xc7, 0x1f,
  0xf0, 0xfb, 0xc3, 0xff, 0xe0, 0xff, 0xff, 0xff, 0xc0, 0xff, 0xff, 0xff,
  0x00, 0xff, 0xbf, 0xff, 0x80, 0xff, 0x1f, 0x7f, 0xc0, 0xff, 0x0f, 0x3e,
  0xc0, 0xcf, 0x07, 0x1c };
static ButtonLabel ColorA3_offi = {
  (unsigned char *)ColorA3_offi_label, (unsigned char *)ColorA3_offi_mask,
  ColorA3_offi_width, ColorA3_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 0, 0, NULL };
static ButtonLook ColorA3_look = {
  &ColorA3_offo, NULL, &ColorA3_offo, NULL,
  &ColorA3_offi, NULL, &ColorA3_offi, NULL };
static ButtonFeel ColorA3_feel = {
  "ColorA3", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 8, 4096, 0, 0 } };
/* thresat button: ColorA4 */
#define ColorA4_offo_width 32
#define ColorA4_offo_height 16
static char ColorA4_offo_label[] = {
  0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x40, 0x1c, 0x00, 0x00, 0x20, 0x3e,
  0x00, 0x00, 0x10, 0x49, 0x00, 0x00, 0x08, 0x08, 0x10, 0x00, 0x04, 0x00,
  0x38, 0x00, 0x02, 0x08, 0x7c, 0x00, 0x01, 0x49, 0x92, 0x80, 0x00, 0x3e,
  0x10, 0x40, 0x00, 0x1c, 0x00, 0x20, 0x00, 0x08, 0x10, 0x10, 0x00, 0x00,
  0x92, 0x08, 0x00, 0x00, 0x7c, 0x04, 0x00, 0x00, 0x38, 0x02, 0x00, 0x00,
  0x10, 0x00, 0x00, 0x00 };
static char ColorA4_offo_mask[] = {
  0x00, 0x00, 0xf0, 0x3f, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0xfc, 0xff,
  0x38, 0x00, 0xfe, 0xff, 0x7c, 0x00, 0xff, 0xff, 0xfe, 0x80, 0xff, 0xff,
  0xff, 0xc1, 0xdf, 0xff, 0xff, 0xe3, 0xcf, 0xff, 0xff, 0xf3, 0xc7, 0xff,
  0xff, 0xfb, 0x83, 0xff, 0xff, 0xff, 0x01, 0x7f, 0xff, 0xff, 0x00, 0x3e,
  0xff, 0x7f, 0x00, 0x1c, 0xff, 0x3f, 0x00, 0x00, 0xfe, 0x1f, 0x00, 0x00,
  0xfc, 0x0f, 0x00, 0x00 };
static ButtonLabel ColorA4_offo = {
  (unsigned char *)ColorA4_offo_label, (unsigned char *)ColorA4_offo_mask,
  ColorA4_offo_width, ColorA4_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 0, 0, NULL };
#define ColorA4_offi_width 32
#define ColorA4_offi_height 16
static char ColorA4_offi_label[] = {
  0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0xe0, 0x1c, 0x00, 0x00, 0x70, 0x3e,
  0x00, 0x00, 0x38, 0x7f, 0x10, 0x00, 0x9c, 0xc9, 0x38, 0x00, 0x0e, 0x08,
  0x7c, 0x00, 0x07, 0x08, 0xfe, 0x80, 0x83, 0xc9, 0x93, 0xc1, 0x01, 0x7f,
  0x10, 0xe0, 0x00, 0x3e, 0x10, 0x70, 0x00, 0x1c, 0x93, 0x39, 0x00, 0x08,
  0xfe, 0x1c, 0x00, 0x00, 0x7c, 0x0e, 0x00, 0x00, 0x38, 0x07, 0x00, 0x00,
  0x10, 0x00, 0x00, 0x00 };
static char ColorA4_offi_mask[] = {
  0x00, 0x00, 0xf0, 0x3f, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0xfc, 0xff,
  0x38, 0x00, 0xfe, 0xff, 0x7c, 0x00, 0xff, 0xff, 0xfe, 0x80, 0xff, 0xff,
  0xff, 0xc1, 0xdf, 0xff, 0xff, 0xe3, 0xcf, 0xff, 0xff, 0xf3, 0xc7, 0xff,
  0xff, 0xfb, 0x83, 0xff, 0xff, 0xff, 0x01, 0x7f, 0xff, 0xff, 0x00, 0x3e,
  0xff, 0x7f, 0x00, 0x1c, 0xff, 0x3f, 0x00, 0x00, 0xfe, 0x1f, 0x00, 0x00,
  0xfc, 0x0f, 0x00, 0x00 };
static ButtonLabel ColorA4_offi = {
  (unsigned char *)ColorA4_offi_label, (unsigned char *)ColorA4_offi_mask,
  ColorA4_offi_width, ColorA4_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 0, 0, NULL };
static ButtonLook ColorA4_look = {
  &ColorA4_offo, NULL, &ColorA4_offo, NULL,
  &ColorA4_offi, NULL, &ColorA4_offi, NULL };
static ButtonFeel ColorA4_feel = {
  "ColorA4", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 8, 8192, 0, 0 } };
/* gamma button: ColorA5 */
#define ColorA5_offo_width 46
#define ColorA5_offo_height 14
static char ColorA5_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x58, 0x1c, 0x9a, 0xd1, 0x0c, 0x07, 0x64, 0x22, 0x66, 0x32, 0x93, 0x08,
  0x42, 0x30, 0x22, 0x12, 0x11, 0x0c, 0x42, 0x2c, 0x22, 0x12, 0x11, 0x0b,
  0x42, 0x22, 0x22, 0x12, 0x91, 0x08, 0x64, 0x22, 0x22, 0x12, 0x91, 0x08,
  0x58, 0x5c, 0x22, 0x12, 0x11, 0x17, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x42, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char ColorA5_offo_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0x3e, 0xff, 0xfb, 0x9f, 0x0f,
  0xfe, 0x7f, 0xff, 0xff, 0xff, 0x1f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x1f,
  0xff, 0x7f, 0xff, 0xff, 0xff, 0x1f, 0xe7, 0x7f, 0x77, 0xbf, 0xfb, 0x1f,
  0xff, 0x7f, 0x77, 0xbf, 0xfb, 0x1f, 0xff, 0xff, 0x77, 0xbf, 0xfb, 0x3f,
  0xfe, 0xff, 0x77, 0xbf, 0xfb, 0x3f, 0xff, 0xfe, 0x77, 0xbf, 0xbb, 0x3f,
  0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int ColorA5_offo_breaks[] = { 8, 16, 27, 38, 46 };
static ButtonLabel ColorA5_offo = {
  (unsigned char *)ColorA5_offo_label, (unsigned char *)ColorA5_offo_mask,
  ColorA5_offo_width, ColorA5_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  6, 5, 0, ColorA5_offo_breaks };
#define ColorA5_offi_width 46
#define ColorA5_offi_height 14
static char ColorA5_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x7e, 0x1e, 0xdf, 0xf9, 0x8e, 0x07, 0x63, 0x33, 0x33, 0x9b, 0xd9, 0x0c,
  0x63, 0x30, 0x33, 0x9b, 0x19, 0x0c, 0x63, 0x3e, 0x33, 0x9b, 0x99, 0x0f,
  0x63, 0x33, 0x33, 0x9b, 0xd9, 0x0c, 0x63, 0x33, 0x33, 0x9b, 0xd9, 0x0c,
  0x7e, 0x6e, 0x33, 0x9b, 0x99, 0x1b, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x63, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char ColorA5_offi_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0x0f,
  0xff, 0xff, 0xff, 0xff, 0xff, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x1f,
  0xf7, 0xff, 0xff, 0xff, 0xff, 0x1f, 0xf7, 0xff, 0xff, 0xff, 0xff, 0x1f,
  0xf7, 0xff, 0xff, 0xff, 0xff, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f,
  0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f,
  0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int ColorA5_offi_breaks[] = { 8, 16, 27, 38, 46 };
static ButtonLabel ColorA5_offi = {
  (unsigned char *)ColorA5_offi_label, (unsigned char *)ColorA5_offi_mask,
  ColorA5_offi_width, ColorA5_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  6, 5, 0, ColorA5_offi_breaks };
static ButtonLook ColorA5_look = {
  &ColorA5_offo, NULL, &ColorA5_offo, NULL,
  &ColorA5_offi, NULL, &ColorA5_offi, NULL };
static ButtonFeel ColorA5_feel = {
  "ColorA5", 2,
  { BTNMode, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 8, 16384, 0, 0 } };
/* invert button: ColorA6 */
#define ColorA6_offo_width 40
#define ColorA6_offo_height 14
static char ColorA6_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00,
  0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x10, 0xd2, 0x11, 0x84, 0xa1,
  0x79, 0x32, 0x12, 0x44, 0x62, 0x10, 0x12, 0x22, 0x22, 0x24, 0x10, 0x12,
  0x22, 0xe2, 0x27, 0x10, 0x12, 0x42, 0x21, 0x20, 0x10, 0x12, 0x42, 0x41,
  0x24, 0x10, 0x12, 0x82, 0x80, 0x23, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char ColorA6_offo_mask[] = {
  0x07, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x38, 0x07, 0x00,
  0x00, 0x00, 0x38, 0xff, 0x3b, 0xce, 0xf3, 0xff, 0xff, 0x3f, 0xee, 0xf7,
  0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0x38, 0x3f,
  0xf7, 0xf7, 0x7f, 0x38, 0x3f, 0xf7, 0xf7, 0x7f, 0x38, 0x3f, 0xe7, 0xf3,
  0x7f, 0xf8, 0x3f, 0xe7, 0xe3, 0x7f, 0xf8, 0x3f, 0xc7, 0xc1, 0x77, 0xf0,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int ColorA6_offo_breaks[] = { 3, 11, 20, 28, 34, 40 };
static ButtonLabel ColorA6_offo = {
  (unsigned char *)ColorA6_offo_label, (unsigned char *)ColorA6_offo_mask,
  ColorA6_offo_width, ColorA6_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 6, 0, ColorA6_offo_breaks };
#define ColorA6_offi_width 40
#define ColorA6_offi_height 14
static char ColorA6_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00,
  0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x00, 0x18, 0xfb, 0x19, 0xe6, 0xf3,
  0x7d, 0x1b, 0x1b, 0x36, 0xb6, 0x19, 0x1b, 0x33, 0x33, 0x36, 0x18, 0x1b,
  0x33, 0xf3, 0x37, 0x18, 0x1b, 0x23, 0x31, 0x30, 0x18, 0x1b, 0xe3, 0x31,
  0x36, 0x18, 0x1b, 0xc3, 0xe0, 0x33, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char ColorA6_offi_mask[] = {
  0x07, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x3c, 0x07, 0x00,
  0x00, 0x00, 0x3c, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0x3f, 0xbf,
  0xff, 0xff, 0x7f, 0x3c, 0xbf, 0xff, 0xff, 0x7f, 0x3c, 0xbf, 0xf7, 0xfb,
  0x7f, 0xfc, 0xbf, 0xf7, 0xfb, 0x7f, 0xfc, 0xbf, 0xe7, 0xf1, 0x7f, 0xf8,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int ColorA6_offi_breaks[] = { 3, 11, 20, 28, 34, 40 };
static ButtonLabel ColorA6_offi = {
  (unsigned char *)ColorA6_offi_label, (unsigned char *)ColorA6_offi_mask,
  ColorA6_offi_width, ColorA6_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 6, 0, ColorA6_offi_breaks };
static ButtonLook ColorA6_look = {
  &ColorA6_offo, NULL, &ColorA6_offo, NULL,
  &ColorA6_offi, NULL, &ColorA6_offi, NULL };
static ButtonFeel ColorA6_feel = {
  "ColorA6", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 8, 128, 0, 0 } };
/* cmap button: ColorA7 */
#define ColorA7_offo_width 35
#define ColorA7_offo_height 14
static char ColorA7_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x9a, 0xe1, 0xd0,
  0x00, 0x44, 0x66, 0x12, 0x31, 0x01, 0x02, 0x22, 0x82, 0x11, 0x02, 0x02,
  0x22, 0x62, 0x11, 0x02, 0x02, 0x22, 0x12, 0x11, 0x02, 0x44, 0x22, 0x12,
  0x31, 0x01, 0x38, 0x22, 0xe2, 0xd2, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00,
  0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00 };
static char ColorA7_offo_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x7c, 0xff, 0xf3, 0xf9, 0x01, 0xfe, 0xff, 0xff, 0xfb,
  0x03, 0xff, 0xff, 0xff, 0xfb, 0x07, 0xef, 0xff, 0xff, 0xfb, 0x07, 0x07,
  0x77, 0xff, 0x3b, 0x07, 0xef, 0x77, 0xff, 0xfb, 0x07, 0xff, 0x77, 0xff,
  0xff, 0x07, 0xfe, 0x77, 0xff, 0xff, 0x03, 0x7c, 0x77, 0xf7, 0xff, 0x01,
  0x00, 0x00, 0x00, 0x38, 0x00, 0x00, 0x00, 0x00, 0x38, 0x00 };
static int ColorA7_offo_breaks[] = { 8, 19, 27, 35 };
static ButtonLabel ColorA7_offo = {
  (unsigned char *)ColorA7_offo_label, (unsigned char *)ColorA7_offo_mask,
  ColorA7_offo_width, ColorA7_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 4, 0, ColorA7_offo_breaks };
#define ColorA7_offi_width 35
#define ColorA7_offi_height 14
static char ColorA7_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0xdf, 0xf1, 0xf8,
  0x01, 0x63, 0x33, 0x9b, 0x19, 0x03, 0x03, 0x33, 0x83, 0x19, 0x03, 0x03,
  0x33, 0xf3, 0x19, 0x03, 0x63, 0x33, 0x9b, 0x19, 0x03, 0x63, 0x33, 0x9b,
  0x19, 0x03, 0x3e, 0x33, 0x73, 0xfb, 0x01, 0x00, 0x00, 0x00, 0x18, 0x00,
  0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00 };
static char ColorA7_offi_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0xfd, 0x03, 0xff, 0xff, 0xff, 0xff,
  0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xf7, 0xff, 0xff, 0xbf, 0x07, 0xf7,
  0xff, 0xff, 0xbf, 0x07, 0xf7, 0xff, 0xff, 0xbf, 0x07, 0xff, 0xff, 0xff,
  0xff, 0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xff, 0xff, 0xff, 0xff, 0x03,
  0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x00, 0x3c, 0x00 };
static int ColorA7_offi_breaks[] = { 8, 19, 27, 35 };
static ButtonLabel ColorA7_offi = {
  (unsigned char *)ColorA7_offi_label, (unsigned char *)ColorA7_offi_mask,
  ColorA7_offi_width, ColorA7_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 4, 0, ColorA7_offi_breaks };
static ButtonLook ColorA7_look = {
  &ColorA7_offo, NULL, &ColorA7_offo, NULL,
  &ColorA7_offi, NULL, &ColorA7_offi, NULL };
static ButtonFeel ColorA7_feel = {
  "ColorA7", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 0, 0, 0 } };
static ButtonSpec ColorA[] = {
  { &ColorA1_look, &ColorA1_feel },
  { &ColorA2_look, &ColorA2_feel },
  { &ColorA3_look, &ColorA3_feel },
  { &ColorA4_look, &ColorA4_feel },
  { &ColorA5_look, &ColorA5_feel },
  { &ColorA6_look, &ColorA6_feel },
  { &ColorA7_look, &ColorA7_feel } };
static BoxGeometry ColorA_geo = 
  { 0, 7, 7, 1, 7.000000, 1.000000, 0.000000, 0.000000, 0, 1 };

void MakeColorPanel ( box, parent, gc, visual, background )
     BoxParent *parent;
     ButtonBox box[1];
     GC gc;
     Visual *visual;
     unsigned long background;
{
  box[0] = MakeButtonBox(&parent[1], gc, visual, background,
			 &ColorA_geo, ColorA, 0);
}
